@@ -29,7 +29,7 @@ class MachineLearningModel(object):
         #     logger.error(message)
         #     raise FileNotFoundError(message)
         mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
-        self.load_model(mypath)
+        self.load_model(str(mypath))
     
     def load_model(self, mypath : str):
         self.model = annhub.ANNHUB(int(MODEL_ID))
